==> xlniuxdata-vipgame-1.0.37-20151124.073103-8-sources.jar: com/xunlei/niux/data/vipgame/vo/CheatingReport.java <==
package com.xunlei.niux.data.vipgame.vo;

import com.ferret.common.dao.annotation.Exclude;
import com.ferret.common.dao.annotation.Table;

@Table(tableName = "cheating_report", pkFieldName = "seqid", pkFieldAssign = false)
public class CheatingReport {
    private Long seqid;
    private String  providerGameId;
    private String  providerServerId;
    private String  providerRoleName;
    private String  providerUserId;
    private String  reportTime;
    private String  cheaterGameId;
    private String  cheaterServerId;
    private String  cheaterRoleName;
    private String  cheaterCustomerId;
    private String  timeOfCheating;
    private String  descOfCheating;
    private String  videoOfCheating;
    private String  urlOfCheating;
    private String  handler;
    private String  handleTime;
    private String  handleDesc;
    private Integer  status;
    private Long  lockSeconds;
    @Exclude
    private String lockSecondsDisplay;

    public String getLockSecondsDisplay() {
        return lockSecondsDisplay;
    }

    public void setLockSecondsDisplay(String lockSecondsDisplay) {
        this.lockSecondsDisplay = lockSecondsDisplay;
    }

    public String getCheaterCustomerId() {
        return cheaterCustomerId;
    }

    public void setCheaterCustomerId(String cheaterCustomerId) {
        this.cheaterCustomerId = cheaterCustomerId;
    }

    public String getCheaterGameId() {
        return cheaterGameId;
    }

    public void setCheaterGameId(String cheaterGameId) {
        this.cheaterGameId = cheaterGameId;
    }

    public String getCheaterRoleName() {
        return cheaterRoleName;
    }

    public void setCheaterRoleName(String cheaterRoleName) {
        this.cheaterRoleName = cheaterRoleName;
    }

    public String getCheaterServerId() {
        return cheaterServerId;
    }

    public void setCheaterServerId(String cheaterServerId) {
        this.cheaterServerId = cheaterServerId;
    }

    public String getDescOfCheating() {
        return descOfCheating;
    }

    public void setDescOfCheating(String descOfCheating) {
        this.descOfCheating = descOfCheating;
    }

    public String getHandleDesc() {
        return handleDesc;
    }

    public void setHandleDesc(String handleDesc) {
        this.handleDesc = handleDesc;
    }

    public String getHandler() {
        return handler;
    }

    public void setHandler(String handler) {
        this.handler = handler;
    }

    public String getHandleTime() {
        return handleTime;
    }

    public void setHandleTime(String handleTime) {
        this.handleTime = handleTime;
    }

    public Long getLockSeconds() {
        return lockSeconds;
    }

    public void setLockSeconds(Long lockSeconds) {
        this.lockSeconds = lockSeconds;
    }

    public String getProviderGameId() {
        return providerGameId;
    }

    public void setProviderGameId(String providerGameId) {
        this.providerGameId = providerGameId;
    }

    public String getProviderRoleName() {
        return providerRoleName;
    }

    public void setProviderRoleName(String providerRoleName) {
        this.providerRoleName = providerRoleName;
    }

    public String getProviderServerId() {
        return providerServerId;
    }

    public void setProviderServerId(String providerServerId) {
        this.providerServerId = providerServerId;
    }

    public String getProviderUserId() {
        return providerUserId;
    }

    public void setProviderUserId(String providerUserId) {
        this.providerUserId = providerUserId;
    }

    public String getReportTime() {
        return reportTime;
    }

    public void setReportTime(String reportTime) {
        this.reportTime = reportTime;
    }

    public Long getSeqid() {
        return seqid;
    }

    public void setSeqid(Long seqid) {
        this.seqid = seqid;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public String getTimeOfCheating() {
        return timeOfCheating;
    }

    public void setTimeOfCheating(String timeOfCheating) {
        this.timeOfCheating = timeOfCheating;
    }

    public String getUrlOfCheating() {
        return urlOfCheating;
    }

    public void setUrlOfCheating(String urlOfCheating) {
        this.urlOfCheating = urlOfCheating;
    }

    public String getVideoOfCheating() {
        return videoOfCheating;
    }

    public void setVideoOfCheating(String videoOfCheating) {
        this.videoOfCheating = videoOfCheating;
    }
}

==> xlniuxdata-vipgame-1.0.65-20161114.061249-32-sources.jar: com/xunlei/niux/data/vipgame/vo/CheatingReport.java <==
package com.xunlei.niux.data.vipgame.vo;

import com.ferret.common.dao.annotation.Exclude;
import com.ferret.common.dao.annotation.Table;

@Table(tableName = "cheating_report", pkFieldName = "seqid", pkFieldAssign = false)
public class CheatingReport {
    private Long seqid;
    private String  providerGameId;
    private String  providerServerId;
    private String  providerRoleName;
    private String  providerUserId;
    private String  reportTime;
    private String  cheaterGameId;
    private String  cheaterServerId;
    private String  cheaterRoleName;
    private String  cheaterCustomerId;
    private String  timeOfCheating;
    private String  descOfCheating;
    private String  videoOfCheating;
    private String  urlOfCheating;
    private String  handler;
    private String  handleTime;
    private String  handleDesc;
    private Integer  status;
    private Long  lockSeconds;
    private Integer cheaterType;
    @Exclude
    private String lockSecondsDisplay;

    public Integer getCheaterType() {
        return cheaterType;
    }

    public void setCheaterType(Integer cheaterType) {
        this.cheaterType = cheaterType;
    }

    public String getLockSecondsDisplay() {
        return lockSecondsDisplay;
    }

    public void setLockSecondsDisplay(String lockSecondsDisplay) {
        this.lockSecondsDisplay = lockSecondsDisplay;
    }

    public String getCheaterCustomerId() {
        return cheaterCustomerId;
    }

    public void setCheaterCustomerId(String cheaterCustomerId) {
        this.cheaterCustomerId = cheaterCustomerId;
    }

    public String getCheaterGameId() {
        return cheaterGameId;
    }

    public void setCheaterGameId(String cheaterGameId) {
        this.cheaterGameId = cheaterGameId;
    }

    public String getCheaterRoleName() {
        return cheaterRoleName;
    }

    public void setCheaterRoleName(String cheaterRoleName) {
        this.cheaterRoleName = cheaterRoleName;
    }

    public String getCheaterServerId() {
        return cheaterServerId;
    }

    public void setCheaterServerId(String cheaterServerId) {
        this.cheaterServerId = cheaterServerId;
    }

    public String getDescOfCheating() {
        return descOfCheating;
    }

    public void setDescOfCheating(String descOfCheating) {
        this.descOfCheating = descOfCheating;
    }

    public String getHandleDesc() {
        return handleDesc;
    }

    public void setHandleDesc(String handleDesc) {
        this.handleDesc = handleDesc;
    }

    public String getHandler() {
        return handler;
    }

    public void setHandler(String handler) {
        this.handler = handler;
    }

    public String getHandleTime() {
        return handleTime;
    }

    public void setHandleTime(String handleTime) {
        this.handleTime = handleTime;
    }

    public Long getLockSeconds() {
        return lockSeconds;
    }

    public void setLockSeconds(Long lockSeconds) {
        this.lockSeconds = lockSeconds;
    }

    public String getProviderGameId() {
        return providerGameId;
    }

    public void setProviderGameId(String providerGameId) {
        this.providerGameId = providerGameId;
    }

    public String getProviderRoleName() {
        return providerRoleName;
    }

    public void setProviderRoleName(String providerRoleName) {
        this.providerRoleName = providerRoleName;
    }

    public String getProviderServerId() {
        return providerServerId;
    }

    public void setProviderServerId(String providerServerId) {
        this.providerServerId = providerServerId;
    }

    public String getProviderUserId() {
        return providerUserId;
    }

    public void setProviderUserId(String providerUserId) {
        this.providerUserId = providerUserId;
    }

    public String getReportTime() {
        return reportTime;
    }

    public void setReportTime(String reportTime) {
        this.reportTime = reportTime;
    }

    public Long getSeqid() {
        return seqid;
    }

    public void setSeqid(Long seqid) {
        this.seqid = seqid;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public String getTimeOfCheating() {
        return timeOfCheating;
    }

    public void setTimeOfCheating(String timeOfCheating) {
        this.timeOfCheating = timeOfCheating;
    }

    public String getUrlOfCheating() {
        return urlOfCheating;
    }

    public void setUrlOfCheating(String urlOfCheating) {
        this.urlOfCheating = urlOfCheating;
    }

    public String getVideoOfCheating() {
        return videoOfCheating;
    }

    public void setVideoOfCheating(String videoOfCheating) {
        this.videoOfCheating = videoOfCheating;
    }
}
